/**
 * Created by liyaoyan on 16/6/1.
 */

define(function (require, exports, module) {
    var $ = require("zepto");

    var ajaxMap = [];
    var ajaxObj;

    $.Request = function (options) {

        // 替换字符串中的 {key} 内容
        var _gsub = function (source, pattern, replacement) {

            var result = '', match;
            while (source.length > 0) {
                match = source.match(pattern);

                if (match) {

                    result += source.slice(0, match.index);

                    result += replacement(match).toString();

                    source = source.slice(match.index + match[0].length);
                } else {
                    result += source;
                    source = '';
                }
            }

            return result;
        };
        // 构造请求地址
        this.buildUrl = function (sourceUrl, urlParams) {
            var pathParams = $.extend(true, {}, urlParams);
            var usedPathParams = [];
            var result = !sourceUrl ? "" : _gsub(sourceUrl, /\{(.+?)\}/,
                function (match) {
                    var key = match[1];
                    var value = pathParams[key];
                    if (value === undefined || value === null) {
                        console.error("Can't found '" + key + "' from urlParams.");
                    }
                    usedPathParams.push(key);
                    return encodeURIComponent(value);
                });
            return result;
        };

        // 构造请求对象, 该对象可以直接用于$.ajax方法
        // 该方法在构造失败时会调用$.error抛出异常
        this.buildResult = function (method, result) {

            result = $.extend(true, {}, $.Request.options.defaults,result);

            var successHandler = result.success;
            var errorHandler = result.error;
            // 序列化请求体
            if (result.serializeRequestBody) {
                try {
                    result.data = result.serializeRequestBody(result);
                } catch (e) {
                    console.error('序列化失败. ' + e.message);
                }
            }

            // 请求成功回调包装方法, 会尝试反序列化返回体
            result.success = function (data, textStatus, jqXHR) {
                if (result.deserializeResponseBody) {
                    try {
                        data = result.deserializeResponseBody(data, result);
                    } catch (e) {
                        console.error('发序列化失败. ' + e.message);
                    }
                }
                if (successHandler)
                    successHandler(data, textStatus, jqXHR);

            };

            // 请求失败回调包装方法, 会尝试反序列化返回体
            result.error = function (jqXHR, textStatus, errorThrown) {
                //如果是终止的就不打印异常信息
                if (textStatus != "abort") {
                    if (textStatus == 'timeout') {//超时,status还有success,error等值的情况
                        alert("访问超时");
                    } else {
                        var message;
                        if (result.deserializeError) {
                            message = result.deserializeError(jqXHR, textStatus, errorThrown, result);
                        } else {
                            message = (jqXHR && jqXHR.responseText) || errorThrown || textStatus;
                        }
                        if (errorHandler) {
                            errorHandler(message, jqXHR, textStatus, errorThrown);
                        }
                    }
                }
            };

            // 构造请求地址
            result.url = this.buildUrl(result.url, result.urlParams);

            result.type = method;

            return result;
        };
        // 立刻发送一个请求, 该请求会捕获构造期异常, 转而调用请求失败回调方法
        this.send = function (method, result) {
            try {
                var r = this.buildResult(method, result);
                ajaxObj = $.ajax(r);
                ajaxMap.push(ajaxObj);
                return ajaxObj;
            } catch (e) {
                console.error(e.message);
            }
        };

        this.getindex = function (method, result) {
            return ajaxMap.indexOf(ajaxObj);
        };
        this.getAjaxObj = function (method, result) {
            return ajaxMap[this.getindex()];
        };

        this.get = function (request) {
            return this.send('GET', request);
        };

        this.post = function (request) {
            return this.send('POST', request);
        };

        this.put = function (request) {
            return this.send('PUT', request);
        };

        this.del = function (request) {
            return this.send('DELETE', request);
        };

        this.getJSON = function (request) {
            var r = this.buildResult("GET", request);
            return $.getJSON(r);
        };

        this.abort = function (ajaxObj) {
            if (ajaxObj) {
                ajaxObj.abort();
            }
        };

        this.abortAll = function () {
            ajaxMap.map(this.abort);
            ajaxMap.length = 0;
        };

    };

    // 配置模板容器
    $.Request.options = {};

    // json 默认配置模板
    $.Request.options.defaults = {
        //baseUrl: seajs.data.vars.baseurl,
        compatible: null,
        dataType: "json",
        contentType: "application/json",
        headers: {
            accept: "application/json",
            //    platform: seajs.data.vars.platform
        },
        timeout: 60000 * seajs.data.vars.timeout,
        beforeSend: function () {//调用前
        },
        // isNeedToken: true, //是否需要token
        serializeRequestBody: function (result) {
            if (JSON && JSON.stringify) {
                return JSON.stringify(result.data);
            } else if ($.toJSON) {
                return $.toJSON(result.data);
            }
            throw new Error('需要序列化');
        },
        deserializeResponseBody: null,
        deserializeError: null,
        // 默认的错误处理
        error: function (message, jqXHR, textStatus, errorThrown) {
            //alert("操作失败，请稍后重试");
        },
        complete: function (XMLHttpRequest, status) { //请求完成后最终执行参数
            if (status == 'timeout') {//超时,status还有success,error等值的情况
                console.log("超时");
            }
        }
    };

    // 初始化默认实例
    //$.rest = new $.Rest();
    var request = new $.Request();
    module.exports = request;
});

