define(function(require,exports,module){
    var AbcUtils = function(){

        this.CHARS = '0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz'.split('');

        this.getUUID = function(len, radix){
            var chars = this.CHARS, uuid = [], i;
            radix = radix || chars.length;

            if (len) {
                // Compact form
                for (i = 0; i < len; i++) uuid[i] = chars[0 | Math.random()*radix];
            } else {
                // rfc4122, version 4 form
                var r;

                // rfc4122 requires these characters
                uuid[8] = uuid[13] = uuid[18] = uuid[23] = '-';
                uuid[14] = '4';

                // Fill in random data.  At i==19 set the high bits of clock sequence as
                // per rfc4122, sec. 4.1.5
                for (i = 0; i < 36; i++) {
                    if (!uuid[i]) {
                        r = 0 | Math.random()*16;
                        uuid[i] = chars[(i == 19) ? (r & 0x3) | 0x8 : r];
                    }
                }
            }
            return uuid.join('');
        }

        this.removeFromArray = function(array,index){
            if(isNaN(index)||index>array.length){return false;}
            for(var i=0,n=0;i<array.length;i++)
            {
                if(array[i]!=array[index]){
                    array[n++]=array[i]
                }
            }
            array.length-=1
        }

        this.formateDate = function(dateObj,fmt){
            var o = {
                "M+": dateObj.getMonth() + 1, //月份
                "d+": dateObj.getDate(), //日
                "h+": dateObj.getHours(), //小时
                "m+": dateObj.getMinutes(), //分
                "s+": dateObj.getSeconds(), //秒
                "q+": Math.floor((dateObj.getMonth() + 3) / 3), //季度
                "S": dateObj.getMilliseconds() //毫秒
            };
            if (/(y+)/.test(fmt)) fmt = fmt.replace(RegExp.$1, (dateObj.getFullYear() + "").substr(4 - RegExp.$1.length));
            for (var k in o)
                if (new RegExp("(" + k + ")").test(fmt)) fmt = fmt.replace(RegExp.$1, (RegExp.$1.length == 1) ? (o[k]) : (("00" + o[k]).substr(("" + o[k]).length)));
            return fmt;
        }

        this.parseDate = function(dateStr){
            var param = dateStr.split(" ");
            var dateParams,timeParams;
            var y, m, d, h,mm,ss;
            if(param instanceof Array && param.length===2){
                dateParams = param[0].split("-");
                timeParams = param[1].split(":");
                if(!param instanceof Array || dateParams.length!==3){
                    return null;
                }else{
                    y = dateParams[0];
                    m = dateParams[1]-1;
                    d = dateParams[2];
                }
                if(!param instanceof Array || timeParams.length!==3){
                    return null;
                }else{
                    h = timeParams[0];
                    mm = timeParams[1];
                    ss = timeParams[2];
                }
                return new Date(y,m,d,h,mm,ss);
            }else if(param instanceof Array && param.length===1){
                dateParams = param[0].split("-");
                if(!param instanceof Array || dateParams.length!==3){
                    return null;
                }else{
                    y = dateParams[0];
                    m = dateParams[1]-1;
                    d = dateParams[2];
                }
                return new Date(y,m,d,0,0,0);
            }else{
                return null;
            }
        }
    }

    module.exports = new AbcUtils();

});