define(function(require,exports,module){

    var $ = require("zepto");
    var rest = require("rest");
    var A = require('agile');
    var uuid;

    var getDistrict = function(districtType,callBack){
        if(!districtType){
            A.showToast("获取行政区域信息失败!");
            return;
        }

        var params = {};
        var url = "/fp/express/init?xzqhjc={xzqhjc}";
        params.xzqhjc = districtType;
        if(districtType=="2"){
            params.sjxzqhszDm = $("#province").val();
            url += "&sjxzqhszDm={sjxzqhszDm}";
        }else if(districtType=="3"){
            params.sjxzqhszDm = $("#city").val();
            url += "&sjxzqhszDm={sjxzqhszDm}";
        }

        rest.get({
            url : url,
            urlParams : params,
            success : function(data){
                var html;
                if(districtType==1) {
                    html = A.template('#tmpl_province').render(data, function () {});
                    $("#province").html(html);
                }else if(districtType==2){
                    html = A.template('#tmpl_city').render(data, function () {});
                    $("#city").html(html);
                }else if(districtType==3){
                    html = A.template('#tmpl_county').render(data, function () {});
                    $("#county").html(html);
                }
                if(callBack) callBack();
            },
            error : function(){
                A.hideMask();
                A.showToast("获取行政区域信息失败!");
            }
        });
    };

    var validFields = function(){
        var xm = $("#xm").val();
        var dh = $("#dh").val();
        var sfzhm = $("#sfzhm").val();
        var province = $("#province").val();
        var provinceName = $("#province option").eq($("#province").attr("selectedIndex")).text();
        var city = $("#city").val();
        var cityName = $("#city option").eq($("#city").attr("selectedIndex")).text();
        var county = $("#county").val();
        var countyName = $("#county option").eq($("#county").attr("selectedIndex")).text();
        var detailStreet = $("#detailStreet").val();
        var yzbm = $("#yzbm").val();
        var sfmrdz;

        if(!xm){
            A.showToast("请输入姓名!");
            return null;
        }
        if(!/^[\u0391-\uFFE5]{2,8}$|^([A-Za-z]{1,10}\s?){1,3}$/.test(xm)){
            A.showToast("姓名不合法!");
            return null;
        }

        if(!dh){
            A.showToast("请输入电话号码!");
            return null;
        }
        if(!/^1[3-9]\d{9}$/.test(dh)){
            A.showToast("手机号码格式不合法!");
            return null;
        }

        if(!sfzhm){
            A.showToast("请输入身份证号码!");
            return null;
        }

        if(!/^\d{6}(19|2\d)?\d{2}(0[1-9]|1[012])(0[1-9]|[12]\d|3[01])\d{3}(\d|X)?$/.test(sfzhm)){
            A.showToast("身份证号码格式不合法!");
            return null;
        }

        if(!province){
            A.showToast("请选择省/直辖市!");
            return null;
        }
        if(!city){
            A.showToast("请选择市!");
            return null;
        }
        if(!county){
            A.showToast("请选择区/县!");
            return null;
        }
        if(!detailStreet){
            A.showToast("请输入街道地址!");
            return null;
        }
        if(detailStreet.length>32){
            A.showToast("街道地址不能超过32个字符!");
            return null;
        }

        if(!yzbm){
            A.showToast("请输入邮政编码!");
            return null;
        }
        if(yzbm.length!=6){
            A.showToast("邮政编码格式不合法!");
            return null;
        }

        if($('#sfmrdz').is(":checked")){
            sfmrdz = "Y";
        }else{
            sfmrdz = "N";
        }

        var UtDmExpressAddressVo = {
            djxh : sessionStorage.getItem("djxh"),
            roleid : sessionStorage.getItem("roleId"),
            province : province,
            city : city,
            county : county,
            address : detailStreet,
            sfmrdz : sfmrdz,
            yzbm : yzbm,
            sfzhm : sfzhm,
            xm : xm,
            dh : dh,
            provinceName : provinceName,
            cityName : cityName,
            countyName : countyName
        };

        return UtDmExpressAddressVo;
    }

    var submitAddr = function(){
        var UtDmExpressAddressVo = validFields();
        if($.isEmptyObject(UtDmExpressAddressVo)) return;

        A.showMask();
        rest.post({
            url : "/fp/express/insert",
            data : UtDmExpressAddressVo,
            success : function(data){
                A.hideMask();
                if(!data || $.isEmptyObject(data)){
                    A.showToast("保存收货地址失败!");
                }else if(data.code!="000" && data.msg){
                    A.showToast(data.msg);
                }else if(data.code=="000" && data.msg){
                    A.showToast(data.msg);
                    A.Controller.back();
                }else{
                    A.showToast("保存收货地址失败!");
                }
            },
            error : function(){
                A.hideMask();
                A.showToast("保存收货地址失败!");
            }
        });

    }

    var updateAddr = function(){
        var UtDmExpressAddressVo = validFields();
        if($.isEmptyObject(UtDmExpressAddressVo)) return;
        UtDmExpressAddressVo.uuid = uuid;

        A.showMask();
        rest.post({
            url : "/fp/express/update",
            data : UtDmExpressAddressVo,
            success : function(data){
                A.hideMask();
                if(!data || $.isEmptyObject(data)){
                    A.showToast("保存收货地址失败!");
                }else if(data.code!="000" && data.msg){
                    A.showToast(data.msg);
                }else if(data.code=="000" && data.msg){
                    A.showToast(data.msg);
                    A.Controller.back();
                }else{
                    A.showToast("保存收货地址失败!");
                }
            },
            error : function(){
                A.hideMask();
                A.showToast("保存收货地址失败!");
            }
        });
    }

    $("#province").on("change",function(){
        A.showMask();
        getDistrict(2,function(){A.hideMask();});
        $("#county").html(A.template('#tmpl_county').render({}));
    });

    $("#city").on("change",function(){
        A.showMask();
        getDistrict(3,function(){A.hideMask();});
    });

    $("#submit_btn").on(A.options.clickEvent,function(e){
        if(!uuid)
            submitAddr();
        else{
            updateAddr();
        }
    });

    $('#addr_add_section').on('sectionshow', function () {
        uuid="";
        var params = A.Component.params(this);
        if(!$.isEmptyObject(params)) uuid = params.uuid;
        if(!uuid){
            $("#addr_add_section header span[name='opt_words']").html("新增");
            getDistrict(1);
        }else{
            $("#addr_add_section header span[name='opt_words']").html("修改");
            A.showMask();
            rest.get({
                url : "/fp/express/selectOne/{uuid}",
                urlParams : {
                    uuid : uuid
                },
                success : function(data){
                    if(!data || $.isEmptyObject(data)){
                        A.hideMask();
                        A.showToast("查询收货地址失败!");
                    }else if(data.code=="000"){
                        getDistrict(1,function(){
                            $("#province option[value='"+data.data.province+"']").attr("selected","selected");
                            getDistrict(2,function(){
                                $("#city option[value='"+data.data.city+"']").attr("selected","selected");
                                getDistrict(3,function(){
                                    $("#county option[value='"+data.data.county+"']").attr("selected","selected");
                                    $("#xm").val(data.data.xm);
                                    $("#dh").val(data.data.dh);
                                    $("#sfzhm").val(data.data.sfzhm);
                                    $("#detailStreet").val(data.data.address);
                                    $("#yzbm").val(data.data.yzbm);
                                    if(data.data.sfmrdz!="Y"){
                                        $("#sfmrdz").prop("checked",false);
                                    }else{
                                        $("#sfmrdz").prop("checked",true);
                                    }
                                    A.hideMask();
                                });
                            });
                        });
                    }else{
                        A.hideMask();
                        A.showToast(data.msg);
                    }
                },
                error : function(){
                    A.hideMask();
                    A.showToast("查询收货地址失败!");
                }
            });
        }
    });

    var clearFields = function(){
        $("#addr_add_article input,select").each(function(){
            if($(this).attr("type")!="checkbox"){
                $(this).val("");
            }else{
                $(this).attr("checked",false);
            }
        });
    };

    $('#addr_add_section').on('sectionhide', function () {
        clearFields();
    });

});