define(function(require, exports, module) {

    var $ = require("zepto");
    var rest = require("rest");
    var A = require('agile');
    var utils = require('utils');

    var $realname_edit_article = $('#realname_edit_article');
    var $realname_btn_container = $('#realname_btn_container');
    var uuid;

    var validFields = function() {
        var gxrVo;
        var name = $realname_edit_article.find('#name').val();
        var type = $realname_edit_article.find('#type').val();
        var type_mc = $realname_edit_article.find("#type option:selected").text();
        var id_type = $realname_edit_article.find('#id_type').val();
        var id_no = $realname_edit_article.find('#id_no').val();
        var mobilePhone = $realname_edit_article.find('#mobilePhone').val();
        var phone = $realname_edit_article.find('#phone').val();
        var yxqq = $realname_edit_article.find('#yxqq').val();
        var yxqz = $realname_edit_article.find('#yxqz').val();

        if (!name) {
            A.showToast("请输入办税人员姓名!");
            return;
        }
        if (!/^[\u0391-\uFFE5]{2,8}$|^([A-Za-z]{1,10}\s?){1,3}$/.test(name)) {
            A.showToast("办税人员姓名不合法!");
            return;
        }

        if (!type) {
            A.showToast('请选择办税人员类型！');
            return;
        }

        if (!id_type) {
            A.showToast('请选择证件类型！');
            return;
        }
        if (!id_no) {
            A.showToast('请输入证件号码！');
            return;
        }
        if (id_type === '201' && !/^\d{6}(19|2\d)?\d{2}(0[1-9]|1[012])(0[1-9]|[12]\d|3[01])\d{3}(\d|X)?$/.test(id_no)) {
            A.showToast("证件号码格式不合法!");
            return;
        } else if (id_no.length < 6) {
            A.showToast("证件号码格式不合法!");
            return;
        }

        if (!mobilePhone) {
            A.showToast("请输入手机号码!");
            return;
        }
        if (!/^1[3-9]\d{9}$/.test(mobilePhone)) {
            A.showToast("手机号码格式不合法!");
            return;
        }

        if (phone && !/^(?:(?:0\d{2,3}[\- ]?[1-9]\d{6,7})|(?:[48]00[\- ]?[1-9]\d{6}))$/.test(phone) && !/^1[3-9]\d{9}$/.test(phone)) {
            A.showToast("固定电话格式不合法!");
            return;
        }

        gxrVo = {
            djxh: sessionStorage.getItem("djxh"),
            xm: name,
            gxrlxDm: type,
            gxrlxmc: type_mc,
            sfzjlxDm: id_type,
            sfzjhm: id_no,
            yddh: mobilePhone,
            gddh: phone,
            rzyxqq: yxqq,
            rzyxqz: yxqz
        };
        if (uuid) {
            gxrVo.gxruuid = uuid;
        }

        return gxrVo;
    }

    var editRealname = function(type) {

        $("#type").prop("disabled",false);
        $("#id_type").prop("disabled",false);

        var gxrVo = validFields();

        if (!gxrVo) return;
        A.showMask();
        rest.post({
            url: "/smrz/addgxr",
            data: gxrVo,
            success: function(json) {
                A.hideMask();
                if (json.code === "000" && json.msg) {
                    if (!gxrVo.gxruuid && json.gxruuid) {
                        gxrVo.gxruuid = json.gxruuid;
                    }
                    A.showToast(json.msg);

                    if (type == "check")
                        A.Controller.section('mine/realname/realname_check_section.html?gxruuid=' + json.gxruuid + '&xm=' + gxrVo.xm + '&gxrlxmc=' + gxrVo.gxrlxmc + '&gxrlxDm=' +gxrVo.gxrlxDm + "&sfzjlxDm="+ gxrVo.sfzjlxDm + "&sfzjhm=" + gxrVo.sfzjhm);
                    else {
                        A.Controller.back();
                    }
                } else {
                    A.showToast(json.msg);
                }
            },
            error: function() {
                A.hideMask();
                A.showToast("保存失败,请稍后重试!");
            }
        });
    }

    $('#realname_edit_section').on('sectionshow', function() {

        if(!sessionStorage.getItem("zgswskfjDm")){
            A.showToast("请先到办税大厅办理管户分配，才能进行在线实名认证！");
            A.Controller.back();
            return;
        }

        // 保存按钮事件
        $realname_btn_container.find("button[name='btn_draft']").off(A.options.clickEvent);
        $realname_btn_container.find("button[name='btn_draft']").on(A.options.clickEvent, function(e) {
            editRealname("draft");
        });

        // 保存并认证按钮事件
        $realname_btn_container.find("button[name='btn_check']").off(A.options.clickEvent);
        $realname_btn_container.find("button[name='btn_check']").on(A.options.clickEvent, function(e) {
            editRealname("check")
        });

        $realname_btn_container.find("button[name='btn_cancel']").off(A.options.clickEvent);
        $realname_btn_container.find("button[name='btn_cancel']").on(A.options.clickEvent, function(e) {
            A.Controller.back();
        });

        setSfzjlx();

        var params = A.Component.params(this);
        if (!$.isEmptyObject(params)) uuid = params.uuid;
        if (uuid) {
            setObject(uuid);
        } else {
            $("#name").prop("readonly",false);
            $("#type").prop("disabled",false);
            $("#id_type").prop("disabled",false);
            $("#id_no").prop("readonly",false);
            $("#mobilePhone").prop("readonly",false);
            $("#phone").prop("readonly",false);
            $("#yxqq").parent("div").data("role","date");
            $("#yxqz").parent("div").data("role","date");
            $("#realname_btn_container button[name='btn_check']").show();
            $("#realname_btn_container button[name='btn_cancel']").hide();
            $realname_edit_article.find('#yxqq').siblings("label").html(utils.getNowDay());
            $realname_edit_article.find('#yxqq').val(utils.getNowDay());
            $realname_edit_article.find('#yxqz').siblings("label").html('9999-12-31');
            $realname_edit_article.find('#yxqz').val('9999-12-31');

            A.showMask();
            rest.get({
                url: "/smrz/getgxrlist?nsrsbh=" + localStorage.getItem('nsrsbh'),
                success: function(json) {
                    A.hideMask();
                    if(json.code && json.code=="000"){
                        if(json.dataList.length==0){
                            A.showToast("未查询到法人及财务负责人信息，请前往大厅办理实名登记!");
                            A.Controller.back();
                            return;
                        }
                        for(var i=0;i<json.dataList.length;i++){
                            if(json.dataList[i].gxrlxDm=="01" && json.dataList[i].rzztDm=="04"){
                                return;
                            }
                            if(json.dataList.length-1==i){
                                A.showToast("需先认证完企业法人代表，方可认证其他干系人!");
                                A.Controller.back();
                                return;
                            }
                        }

                    }else{
                        A.showToast(json.msg);
                        A.Controller.back();
                    }
                },
                error: function() {
                    A.hideMask();
                    A.showToast("获取办税人员信息失败，请稍后重试！");
                    A.Controller.back();
                }
            });
        }
    });

    var setSfzjlx = function() {
        A.showMask();
        rest.get({
            url: "/common/code/papertype",
            async: false,
            success: function(json) {
                A.hideMask();
                if (json.code && json.code === '000') {
                    $realname_edit_article.find('#id_type').empty().append('<option value=""> -- 请选择 -- </option>');
                    if (json.result && json.result.length > 0) {
                        var list = json.result;
                        $.each(list, function(i) {
                            $realname_edit_article.find('#id_type')
                                .append('<option value="' + list[i].paperDm + '">' + list[i].paperMc + '</option>');
                        });
                    }
                } else {
                    A.showToast(json.msg);
                    A.Controller.back();
                }
            },
            error: function() {
                A.hideMask();
                A.showToast("获取身份证件信息失败，请稍后重试！");
                A.Controller.back();
            }
        });
    }

    var setObject = function(uuid) {
        A.showMask();
        rest.get({
            url: "/smrz/getgxrlist?nsrsbh=" + localStorage.getItem('nsrsbh'),
            success: function(json) {
                A.hideMask();
                if (json.code && json.code === '000') {
                    if (json.dataList && json.dataList.length > 0) {
                        for (var i = 0, dataList = json.dataList; i < dataList.length; i++) {
                            if (dataList[i].gxruuid === uuid) {
                                var data = dataList[i];
                                if (data.xm) $realname_edit_article.find('#name').val(data.xm);
                                if (data.gxrlxDm) $realname_edit_article.find('#type').val(data.gxrlxDm);
                                if (data.sfzjlxDm) $realname_edit_article.find('#id_type').val(data.sfzjlxDm);
                                if (data.sfzjhm) $realname_edit_article.find('#id_no').val(data.sfzjhm);
                                if (data.yddh) $realname_edit_article.find('#mobilePhone').val(data.yddh);
                                if (data.gddh) $realname_edit_article.find('#phone').val(data.gddh);
                                if (data.rzyxqq) {
                                    $realname_edit_article.find('#yxqq').siblings("label").html(data.rzyxqq);
                                    $realname_edit_article.find('#yxqq').val(data.rzyxqq);
                                } else {
                                    $realname_edit_article.find('#yxqq').siblings("label").html(utils.getNowDay());
                                    $realname_edit_article.find('#yxqq').val(utils.getNowDay());
                                }
                                if (data.rzyxqz) {
                                    $realname_edit_article.find('#yxqz').siblings("label").html(data.rzyxqz);
                                    $realname_edit_article.find('#yxqz').val(data.rzyxqz);
                                } else {
                                    $realname_edit_article.find('#yxqz').siblings("label").html('9999-12-31');
                                    $realname_edit_article.find('#yxqz').val('9999-12-31');
                                }
                                if (data.rzztDm === '01' || data.rzztDm === '06') {
                                    $realname_edit_article.find('#name').prop('readonly', false);
                                    $realname_edit_article.find('#type').prop('disabled', false);
                                    $realname_edit_article.find('#id_type').prop('disabled', false);
                                    $realname_edit_article.find('#id_no').prop('readonly', false);
                                    $realname_edit_article.find('#mobilePhone').prop('readonly', false);
                                    $realname_edit_article.find('#phone').prop('readonly', false);
                                    $('#yxqq').parent("div").data('role',"date");
                                    $('#yxqz').parent("div").data('role',"date");
                                } else {
                                    if (data.gxrlxDm === '01' || data.gxrlxDm === '02') {
                                        $realname_edit_article.find('#mobilePhone').prop('readonly', true);
                                        $realname_edit_article.find('#phone').prop('readonly', true);
                                        $("#realname_btn_container button[name='btn_check']").show();
                                        $("#realname_btn_container button[name='btn_cancel']").hide();
                                    } else {
                                        $realname_edit_article.find('#mobilePhone').prop('readonly', false);
                                        $realname_edit_article.find('#phone').prop('readonly', false);
                                        $("#realname_btn_container button[name='btn_check']").hide();
                                        $("#realname_btn_container button[name='btn_cancel']").show();
                                    }
                                    $realname_edit_article.find('#name').prop('readonly', true);
                                    $realname_edit_article.find('#type').prop('disabled', true);
                                    $realname_edit_article.find('#id_type').prop('disabled', true);
                                    $realname_edit_article.find('#id_no').prop('readonly', true);
                                    $('#yxqq').parent("div").data('role',"");
                                    $('#yxqz').parent("div").data('role',"");
                                }
                                break;
                            }
                        }
                    }
                } else {
                    A.showToast(json.msg);
                    A.Controller.back();
                }
            },
            error: function() {
                A.hideMask();
                A.showToast("获取办税人员信息失败，请稍后重试！");
                A.Controller.back();
            }
        });
    }

    var clearFields = function() {
        $("#realname_edit_article input,select").each(function() {
            if ($(this).attr("type") != "checkbox") {
                $(this).val("");
            } else {
                $(this).attr("checked", false);
            }
        });
    };

    $('#realname_edit_section').on('sectionhide', function() {
        clearFields();
    });

});