define(function (require, exports, module) {
    var $ = require("zepto");
    var A = require("agile");
    var rest = require("rest");
    var math = require("math");

    var lqfsList,reqParam;

    var generateUuid = function(len,radix){
        var chars = '0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz'.split('');
        var uuid = [], i;
        radix = radix || chars.length;
        if (len) {
            // Compact form
            for (i = 0; i < len; i++) uuid[i] = chars[0 | Math.random()*radix];
        } else {
            // rfc4122, version 4 form
            var r;

            // rfc4122 requires these characters
            uuid[8] = uuid[13] = uuid[18] = uuid[23] = '-';
            uuid[14] = '4';

            // Fill in random data. At i==19 set the high bits of clock sequence as
            // per rfc4122, sec. 4.1.5
            for (i = 0; i < 36; i++) {
                if (!uuid[i]) {
                    r = 0 | Math.random()*16;
                    uuid[i] = chars[(i == 19) ? (r & 0x3) | 0x8 : r];
                }
            }
        }
        return uuid.join('');
    };

    var initData = function(){
        rest.get({
            url: "/fp/zrrdk/init?djxh={djxh}",
            urlParams : {
                djxh : $("#msfpdk_form_xsfxx input[name='djxh']").val()
            },
            success: function (result) {
                lqfsList = result.fplqfsList;
                A.template("#tmpl_xhfyh").renderReplace(result);
                A.template("#tmpl_ghfyh").renderReplace(result);
                A.template("#msdkfp_hwys_jldw_tmpl").renderReplace(result);
                // A.template("#msdkfp_lyfs_select_tmpl").renderReplace({fplqfsList:lqfsList});
                A.template("#tmpl_msdkfp_zspm").renderReplace({});
                A.template("#lqbst_select_tmpl").renderReplace({});
                A.template("#tmpl_dkrlx").renderReplace(result);
                A.template("#xzqh_lyfs_select_tmpl").renderReplace(result);
                // onGhfyhchg();
                // onXzqhchg();

                if(result.nsrxx) {
                    $("#msfpdk_form_xsfxx input[name='fpdk.xhdwdz']").val(result.nsrxx.zcdz);
                    $("#msfpdk_form_xsfxx select[name='fpdk.xhdwyhdm']").val(result.nsrxx.yhhbDm);
                    $("#msfpdk_form_xsfxx input[name='fpdk.xhdwkhyh']").val(result.nsrxx.yhyywdmc);
                    $("#msfpdk_form_xsfxx input[name='fpdk.xhdwyhkh']").val(result.nsrxx.yhzh);
                    $("#msfpdk_form_xsfxx input[name='fpdk.xhdwdhhm']").val(result.nsrxx.zcdlxdh);
                }


                initBtnEvent();
                initModalEvent();
                A.hideMask();
            },
            error: function () {
                A.showToast("初始化失败");
                A.Controller.back();
                A.hideMask();
            }
        });
    }

    var initBtnEvent = function(){

        $("#msfpdk_hwys_add_article button[name='btn_saveHwys']").off(A.options.clickEvent).on(A.options.clickEvent,function(){
            if(!validHwysxx()){
                return;
            }
            if($("#msfpdk_hwys_add_article input[name='hwysUUID']").val()){
                updateHwysxx();
            }else{
                saveHwysxx();
            }
        });

        $("#msfpdk_lyfs_info_form div[name='a_swjg_btn_container']").off(A.options.clickEvent).on(A.options.clickEvent,function(){

            var xzqh = $("#xzqh_lyfs_select").val();
            if(!xzqh){
                A.showToast("请选择行政区划");
                return;
            }

            A.Controller.modal("#msfpdk_swjg_modal");
        });

        $("#msdkfp_add_article button[name='submit_btn']").off(A.options.clickEvent).on(A.options.clickEvent, function () {
            if (validMsdkfpForm()) {
                var dkrlx = $("#msdkfp_dkrlx").val();
                var swdjh = $("#msfpdk_form_xsfxx input[name='fpdk.xhdwswdjh']").val();
                if (dkrlx == "2") {
                    A.showMask();
                    rest.get({
                        url: "/fp/zrrdk/sfxgm/{nsrsbh}",
                        urlParams: {
                            nsrsbh: swdjh
                        },
                        success: function (result) {
                            if (result && result.fpdkbz == "Y") {
                                var wsztDm = $(this).data("wsztdm");
                                if (wsztDm == 'A') {//草稿

                                    $("#msdkfp_confirm_article p[name='confirm_xhdwswdjh']").text($("#msfpdk_form_xsfxx input[name='fpdk.xhdwswdjh']").val());
                                    $("#msdkfp_confirm_article p[name='confirm_xhdwdhhm']").text($("#msfpdk_form_xsfxx input[name='fpdk.xhdwdhhm']").val());

                                    if($("#msdkfp_lyfs_select").val()===1){
                                        $("#msdkfp_confirm_article p[name='confirm_qprsfzhm']").text($("#msfpdk_lyfs_info_form input[name='fpdk.sfzjhm']").val());
                                        $("#msdkfp_confirm_article p[name='confirm_qprsjhm']").text($("#msfpdk_lyfs_info_form input[name='fpdk.yddh']").val());
                                    }else{
                                        $("#msdkfp_confirm_article p[name='confirm_qprsfzhm']").text($("#msfpdk_lyfs_info_form input[name='kd.sfzjhm']").val());
                                        $("#msdkfp_confirm_article p[name='confirm_qprsjhm']").text($("#msfpdk_lyfs_info_form input[name='kd.dhhm']").val());
                                    }


                                    A.Controller.modal("#msdkfp_confirm_modal");
                                } else {
                                    A.Controller.modal("#msdkfp_ynsk_modal");
                                }
                            } else if (result && result.fpdkbz == "N") {
                                A.hideMask();
                                A.showToast("您是一般纳税人，不符合代开增值税普通发票申请的条件.");
                            } else if (result && result.msg && result.code != "000") {
                                A.hideMask();
                                A.showToast(result.msg);
                            } else {
                                A.hideMask();
                                A.showToast("纳税人信息查验失败");
                            }
                        },
                        error: function () {
                            A.hideMask();
                            A.showToast("纳税人信息查验失败");
                        }
                    });
                } else {
                    var wsztDm = $(this).data("wsztdm");
                    if (wsztDm == 'A') {//草稿

                        $("#msdkfp_confirm_article p[name='confirm_xhdwswdjh']").text($("#msfpdk_form_xsfxx input[name='fpdk.xhdwswdjh']").val());
                        $("#msdkfp_confirm_article p[name='confirm_xhdwdhhm']").text($("#msfpdk_form_xsfxx input[name='fpdk.xhdwdhhm']").val());

                        $("#msdkfp_confirm_article p[name='confirm_qprsfzhm']").text($("#msfpdk_lyfs_info_form input[name='fpdk.sfzjhm']").val());
                        $("#msdkfp_confirm_article p[name='confirm_qprsjhm']").text($("#msfpdk_lyfs_info_form input[name='fpdk.yddh']").val());

                        A.Controller.modal("#msdkfp_confirm_modal");
                    } else {
                        A.Controller.modal("#msdkfp_ynsk_modal");
                    }
                }
            }
        });

        $("#msfpdk_hwys_list_modal").on("modalshow",function(){

            $("#msfpdk_hwys_list_modal button[name='msdkfp_query_hwys_btn']").off(A.options.clickEvent).on(A.options.clickEvent,function(){
                var hwysText = $("#msfpdk_hwys_list_modal input[name='msdkfp_query_hwys_text']").val();

                if(!hwysText||hwysText.length<2){
                    A.showToast("请输入两个以上的汉字进行查询");
                    return;
                }

                A.showMask();
                rest.get({
                    url : '/fp/zrrdk/hwlw/{hwmc}',
                    urlParams : {
                        hwmc : hwysText
                    },
                    success : function(queryData){
                        A.hideMask();
                        A.template("#msfpdk_hwys_list_tmpl").renderReplace(queryData);
                        $("#msfpdk_hwys_list_article li[name='msfpdk_hwys_singleitem']").off(A.options.clickEvent).on(A.options.clickEvent,function(){

                            var savedHwys = JSON.parse(sessionStorage.getItem("msfpdk_hwys"))||[];
                            if(savedHwys.length>0){
                                var curZspmmc = $(this).data("zspmmc");
                                var curZspmDm = $(this).data("zspmdm");
                                var curZsl = $(this).data("zsl");

                                var exeType = $("#msfpdk_hwys_add_modal input[name='exeType']").val();
                                if(curZspmmc!=savedHwys[0].zspmmc || curZspmDm!=savedHwys[0].zspmDm || curZsl!=savedHwys[0].zsl){
                                    if(savedHwys.length!=1 || exeType!="update"){
                                        A.showToast("新增的货物或应税劳务、服务名称对应的征收品目与第一条的征收品目不符，请分别提交代开发票申请单。");
                                        return;
                                    }
                                }

                            }

                            $("#msfpdk_hwys_add_article span[name='mc']").text($(this).text());
                            $("#msfpdk_hwys_add_article input[name='zspmmc']").val($(this).data("zspmmc"));
                            $("#msfpdk_hwys_add_article input[name='zspmDm']").val($(this).data("zspmdm"));
                            $("#msfpdk_hwys_add_article input[name='zsl']").val($(this).data("zsl"));
                            $("#msfpdk_hwys_add_article input[name='ssbm']").val($(this).data("hwbm"));

                            autoCalculate($("#msfpdk_hwys_add_article input[name='hsdj']"));

                            A.Controller.modal("#msfpdk_hwys_list_modal");
                        });
                    },
                    error : function(){
                        A.hideMask();
                        A.showToast("查询货物劳务服务失败");
                    }
                });
            });
        });

        $("#msfpdk_hwys_list_modal").on("modalhide",function(){
            $("#msfpdk_hwys_list_modal input[name='msdkfp_query_hwys_text']").val('');
            A.template("#msfpdk_hwys_list_tmpl").renderReplace({});
        });

        $("#msdkfp_confirm_modal").on("modalshow",function(){
            $("#msdkfp_confirm_article button[name='submit_btn']").off(A.options.clickEvent);
            $("#msdkfp_confirm_article button[name='submit_btn']").on(A.options.clickEvent,function(){
                submitForm("A");
            });

            $("#msdkfp_confirm_modal a[name='back_confirm_modal']").off(A.options.clickEvent);
            $("#msdkfp_confirm_modal a[name='back_confirm_modal']").on(A.options.clickEvent,function(){
                A.Controller.modal("#msdkfp_confirm_modal");
            });
        });

        $("#msdkfp_add_article button[name='gmf_nsrxx_btn']").off(A.options.clickEvent).on(A.options.clickEvent,function(){
            var swdjh = $("#msfpdk_form_gmfxx input[name='fpdk.ghdwswdjh']").val();
            if(!swdjh){
                A.showToast("请输入购买方纳税人识别号/身份证号码");
                return;
            }
            A.showMask();
            rest.get({
                url: "/fp/zrrdk/getnsrxx?cxlx=1&swdjh={swdjh}",
                urlParams : {
                    swdjh : swdjh
                },
                success: function(data) {
                    A.hideMask();
                    if (!$.isEmptyObject(data) && data.code == "000") {
                        var nsrxx = data.nsrxx;
                        $("#msfpdk_form_gmfxx input[name='fpdk.ghdwmc']").val(nsrxx.nsrmc);
                        $("#msfpdk_form_gmfxx input[name='fpdk.ghdwdz']").val(nsrxx.zcdz);
                        $("#msfpdk_form_gmfxx select[name='fpdk.ghdwyhdm']").val(nsrxx.yhhbDm);
                        $("#msfpdk_form_gmfxx input[name='fpdk.ghdwkhyh']").val(nsrxx.yhyywdmc);
                        $("#msfpdk_form_gmfxx input[name='fpdk.ghdwyhkh']").val(nsrxx.yhzh);
                        $("#msfpdk_form_gmfxx input[name='fpdk.ghdwdhhm']").val(nsrxx.zcdlxdh);

                        A.template("#msdkfp_addr_list_tmpl").renderReplace(data);
                    } else {
                        A.showToast(data.msg);
                    }
                },
                error: function(err) {
                    A.hideMask();
                    A.showToast('查询纳税人信息');
                }
            });
        });

        $("#msdkfp_add_article button[name='xhf_nsrxx_btn']").off(A.options.clickEvent).on(A.options.clickEvent,function(){
            var swdjh = $("#msfpdk_form_xsfxx input[name='fpdk.xhdwswdjh']").val();
            if(!swdjh){
                A.showToast("请输入销售方纳税人识别号/身份证号码");
                return;
            }

            A.showMask();
            rest.get({
                url: "/fp/zrrdk/getnsrxx?cxlx=2&swdjh={swdjh}",
                urlParams: {
                    swdjh: swdjh
                },
                success: function (data) {
                    A.hideMask();
                    if (!$.isEmptyObject(data) && data.code == "000") {
                        var nsrxx = data.nsrxx;

                        $("#msfpdk_form_xsfxx").find("input,select").each(function(){
                            if(!$(this).data("getnsrxxname"))
                                return;
                            $(this).val(nsrxx[$(this).data("getnsrxxname")]);
                        });

                        A.template("#msdkfp_addr_list_tmpl").renderReplace(data,function(){
                            $("#msdkfp_select_addr_modal button[name='msdkfp_addr_usage_btn']").off(A.options.clickEvent).on(A.options.clickEvent,function(){
                                $("#msdkfp_lyfs_express input[name='kd.sjr']").val($(this).data("sjr"));
                                $("#msdkfp_lyfs_express input[name='kd.dhhm']").val($(this).data("dhhm"));
                                $("#msdkfp_lyfs_express input[name='kd.dz']").val($(this).data("dz"));
                                $("#msdkfp_lyfs_express input[name='kd.sfzjhm']").val($(this).data("sfzjhm"));
                                $("#msdkfp_lyfs_express input[name='kd.yzbm']").val($(this).data("yzbm"));
                                A.Controller.modal("#msdkfp_select_addr_modal");
                            })
                        });
                        var addrList = data.addressList,defaultAddr;
                        for(var i in addrList){
                            if(addrList[i].sfmrdz=="Y"){
                                defaultAddr = addrList[i];
                                break;
                            }
                        }
                        if(defaultAddr) {
                            $("#msdkfp_lyfs_express input[name='kd.sjr']").val(defaultAddr.xm);
                            $("#msdkfp_lyfs_express input[name='kd.dhhm']").val(defaultAddr.dh);
                            $("#msdkfp_lyfs_express input[name='kd.dz']").val(defaultAddr.provinceName + defaultAddr.cityName + defaultAddr.countyName + defaultAddr.address);
                            $("#msdkfp_lyfs_express input[name='kd.sfzjhm']").val(defaultAddr.sfzhm);
                            $("#msdkfp_lyfs_express input[name='kd.yzbm']").val(defaultAddr.yzbm);
                        }

                    } else {
                        A.showToast(data.msg);
                    }
                },
                error: function (err) {
                    A.hideMask();
                    A.showToast('查询纳税人信息');
                }
            });

        });

        $("#msdkfp_ynsk_article button[name='submit_btn']").off(A.options.clickEvent).on(A.options.clickEvent,function(){
            submitForm($(this).data("wsztdm"));
        });

        $("#msdkfp_lyfs_select").off("change").on("change",function(){
            var formType = $(this).find("option:selected").data("formtype");
            if (formType == 'self') {
                $("#msdkfp_lyfs_express").hide();
                $("#msdkfp_lyfs_terminal").show();
            }else if(formType == 'express'){
                $("#msdkfp_lyfs_express").show();
                $("#msdkfp_lyfs_terminal").hide();
            } else {
                $("#msdkfp_lyfs_express").hide();
                $("#msdkfp_lyfs_terminal").hide();
            }
            A.Scroll("#msdkfp_add_article").refresh();
        }).trigger("change");

        $("#xzqh_lyfs_select").off("change").on("change", function () {
            $("#msdkfp_component_xzjd input[name='jdxzmc']").val("");
            $("#msdkfp_component_xzjd input[name='jdxzdm']").val("");
            $("#msdkfp_component_xzjd input[name='qxxzqhdm']").val("");
            A.template("#msdkfp_swjg_list_tmpl").renderReplace({});
            $("#msdkfp_swjg_list_select").val("");
            A.Scroll("#msdkfp_add_article").refresh();
        });

        $("#msdkfp_swjg_list_select").off("change").on("change", function () {

            var swjgDm = $(this).val();
            if(!swjgDm)
                return;

            A.showMask();
            rest.get({
                url : "/fp/zrrdk/lqfs/{swjgdm}",
                urlParams : {
                    swjgdm : swjgDm
                },
                success : function(lqfsResult){
                    if(lqfsResult && lqfsResult.code=='000') {
                        var bstLqfs = lqfsResult.fplqfs.split(",");
                        var renderParam = [];
                        for (var i in lqfsList) {
                            for (var j in bstLqfs) {
                                if (lqfsList[i].fplqfsDm == bstLqfs[j]) {
                                    switch (lqfsList[i].fplqfsDm) {
                                        case "1": {
                                            lqfsList[i].fplqfsForm = "self";
                                            break;
                                        }
                                        case "3": {
                                            lqfsList[i].fplqfsForm = "self";
                                            break;
                                        }
                                        default: {
                                            lqfsList[i].fplqfsForm = "express";
                                            break;
                                        }
                                    }
                                    renderParam.push(lqfsList[i]);
                                    break;
                                }
                            }
                        }
                        A.template("#msdkfp_lyfs_select_tmpl").renderReplace({fplqfsList: renderParam});
                    } else {
                        A.showToast(lqfsResult.msg);
                    }

                },
                error : function(){
                    A.showToast("查询领取方式失败");
                },
                complete : function(){
                    A.hideMask();
                }
            });

        });

        A.Scroll("#msdkfp_add_article").refresh();
    };

    var initModalEvent = function(){
        $("#msfpdk_hwys_add_modal").on("modalshow",function(){
            $("#msfpdk_hwys_add_article input[name='hwsl'],#msfpdk_hwys_add_article input[name='hsdj'],#msfpdk_hwys_add_article input[name='hsje']").off('input').on('input',function(){
                autoCalculate($(this));
            });

            if($("#msfpdk_hwys_add_modal input[name='ssbm']").val()){
                $("#msfpdk_hwys_add_modal input[name='hwsl']").prop("readonly",false).prop("placeholder","请填写数量");
                $("#msfpdk_hwys_add_modal input[name='hsdj']").prop("readonly",false).prop("placeholder","请填写单价");
                $("#msfpdk_hwys_add_modal input[name='hsje']").prop("readonly",false).prop("placeholder","请输入含税销售额");
            }

        });

        $("#msfpdk_hwys_add_modal").live("modalhide",function(){
            $("#msfpdk_hwys_add_article form").get(0).reset();
            $("#msfpdk_hwys_add_article span[name='mc']").text('');
            $("#msfpdk_hwys_add_article input[type='hidden']").val('');

            $("#msfpdk_hwys_add_modal input[name='hwsl']").prop("readonly",true).prop("placeholder","请选择劳务货物信息");
            $("#msfpdk_hwys_add_modal input[name='hsdj']").prop("readonly",true).prop("placeholder","请选择劳务货物信息");
            $("#msfpdk_hwys_add_modal input[name='hsje']").prop("readonly",true).prop("placeholder","请选择劳务货物信息");
        });

        $("#msfpdk_hwys_modal").live("modalhide",function(){
            var hwysList = JSON.parse(sessionStorage.getItem("msfpdk_hwys"));
            var sumSe = 0,sumJe = 0,sumSjhj=0,zspmdm;
            for(var i in hwysList){
                zspmdm = hwysList[i].zspmDm;

                sumSe = math.add(sumSe,hwysList[i].se);
                sumSjhj = math.add(sumSjhj,hwysList[i].hsje);
                sumJe = math.add(sumJe,math.multiply(hwysList[i].hwsl||"1",hwysList[i].bhsdj));
            }
            sumSjhj = math.round(sumSjhj,2);
            sumJe = math.round(sumJe,2);
            sumSe = math.round(sumSe,2);
            $("#msdkfp_add_article input[name='fpdk.sjhj']").val(sumSjhj);
            $("#msdkfp_add_article input[name='fpdk.hjje']").val(sumJe);
            $("#msdkfp_add_article input[name='fpdk.hjse']").val(sumSe);
            $("#msdkfp_form_fpdkxx input[name='zspmdm']").val(zspmdm);
        });

        $("#msfpdk_hwys_modal").on("modalshow",function(){
            var result ;
            try{
                result = JSON.parse(sessionStorage.getItem("msfpdk_hwys"));
            }catch(e){
                result = {}
                sessionStorage.removeItem("msfpdk_hwys");
            }
            A.template("#msfpdk_hwys_tmpl").renderReplace({hwysList:result},function(){
                $("#msfpdk_hwys_article button[name='hwys_update_btn']").off(A.options.clickEvent).on(A.options.clickEvent,function(){

                    var hwysUUID = $(this).data("hwysuuid");

                    var hwysList = JSON.parse(sessionStorage.getItem("msfpdk_hwys"));
                    var target;
                    for(var i in hwysList){
                        if(hwysUUID==hwysList[i].hwysUUID){
                            target = hwysList[i];
                            break;
                        }
                    }
                    if(!target){
                        return;
                    }

                    $("#msfpdk_hwys_add_article").find("input,select").each(function(){
                        $(this).val(target[$(this).prop("name")]);
                    });
                    $("#msfpdk_hwys_add_article span[name='mc']").text(target.mc);
                    $("#msfpdk_hwys_add_article input[name='exeType']").val("update");

                    A.Controller.modal("#msfpdk_hwys_add_modal");
                });

                $("#msfpdk_hwys_article button[name='hwys_del_btn']").off(A.options.clickEvent);
                $("#msfpdk_hwys_article button[name='hwys_del_btn']").on(A.options.clickEvent,function(){
                    A.showMask();

                    var targetParentNode = $(this).parents(".hwys-block");
                    var hwysUUID = $(this).data("hwysuuid");

                    var hwysList = JSON.parse(sessionStorage.getItem("msfpdk_hwys"));
                    for(var i in hwysList){
                        if(hwysUUID==hwysList[i].hwysUUID){
                            hwysList.splice(i,1);
                            break;
                        }
                    }
                    sessionStorage.setItem("msfpdk_hwys",JSON.stringify(hwysList));

                    setTimeout(function(){
                        targetParentNode.remove();
                        A.showToast("删除成功");
                        A.hideMask();
                    },500);
                });

                $("#msfpdk_hwys_modal a[name='back_hwys_modal']").off(A.options.clickEvent);
                $("#msfpdk_hwys_modal a[name='back_hwys_modal']").on(A.options.clickEvent,function(){
                    A.Controller.modal("#msfpdk_hwys_modal");
                });
            });

        });

        $("#msdkfp_ynsk_modal").on("modalshow",function(){

            var bhsxsje = 0;
            var storedHwys = JSON.parse(sessionStorage.getItem("msfpdk_hwys"));
            for(var i in storedHwys){
                bhsxsje = math.add(bhsxsje,storedHwys[i].bhsje);
            }

            var zspmDm = $("#msdkfp_form_fpdkxx input[name='zspmdm']").val();
            var dkrlx = $("#msdkfp_dkrlx").val();
            var zgswjg = $("#msdkfp_swjg_list_select").val();
            var xhdwswdjh = $("#msfpdk_form_xsfxx input[name='fpdk.xhdwswdjh']").val();
            var ssbm = storedHwys[0].ssbm;
            var djxh = $("#msfpdk_form_xsfxx input[name='djxh']").val();
            if(!bhsxsje||!zspmDm||!dkrlx||!djxh) {
                A.showToast("请填写代开文书信息");
                A.Controller.modal("#msdkfp_ynsk_modal");
            }

            var urlParams;
            if(dkrlx==1){
                urlParams = {
                    bhsxsje: bhsxsje,
                    zspmDm: zspmDm,
                    dkrlx: dkrlx,
                    zgswjg: zgswjg,
                    xhdwswdjh : '',
                    ssbm : ssbm,
                    djxh : djxh
                };
            }else if(dkrlx==2){
                if(!xhdwswdjh){
                    A.showToast("请填写销售方纳税人识别号");
                    return;
                }
                urlParams = {
                    bhsxsje: bhsxsje,
                    zspmDm: zspmDm,
                    dkrlx: dkrlx,
                    zgswjg: zgswjg,
                    xhdwswdjh : xhdwswdjh,
                    ssbm : ssbm,
                    djxh : djxh
                };
            }else{
                A.showToast("请代开人类型");
                return;
            }

            A.showMask();
            rest.get({
                url : '/fp/zrrdk/ynsk?hjje={bhsxsje}&zspmDm={zspmDm}&dkrlx={dkrlx}&zgswjg={zgswjg}&xhdwswdjh={xhdwswdjh}&ssbm={ssbm}&&djxh={djxh}',
                urlParams : urlParams,
                success : function(result){
                    A.hideMask();
                    if(result.code=='000') {
                        A.template('#msdkfp_ynsk_tmpl').renderReplace(result);
                    }else{
                        A.showToast(result.msg);
                        A.Controller.modal("#msdkfp_ynsk_modal");
                    }

                },
                error : function(){
                    A.hideMask();
                    A.showToast("查询应纳税款失败");
                    A.Controller.modal("#msdkfp_ynsk_modal");
                }
            });

            $("#msdkfp_ynsk_modal a[name='back_ynsk_modal']").off(A.options.clickEvent);
            $("#msdkfp_ynsk_modal a[name='back_ynsk_modal']").on(A.options.clickEvent,function(){
                A.Controller.modal("#msdkfp_ynsk_modal");
            });

        });

        var subSwjgEaseIn = function($target){
            $target.find("i.iconline-arrow-right").animate({
                rotate : "0deg"
            },200);
            $target.find("div[name='msdkfp-subswjg']").animate({
                height:"0"
            },200,'ease-in-out',function(){
                $target.find("div[name='msdkfp-subswjg']").remove();
            });
        }

        var subSwjgEaseOut = function($target,param,callback){

            var height = typeof(param.jdxzList)=='object'&&param.jdxzList.length*46||0;

            $target.find("div.msdkfp-swjg-container").after(A.template("#msdkfp-subswjg-tmpl").render(param));
            callback();
            //箭头变化
            $target.find("i.iconline-arrow-right").animate({
                rotate : "90deg"
            },200);
            $target.find("div[name='msdkfp-subswjg']").animate({
                height: height+"px"
            },200,"ease-in-out",function(){
                A.Scroll("#msfpdk_swjg_article").refresh();
            });
        }

        $("#msfpdk_swjg_modal").on("modalshow", function () {
            var xzqh = $("#xzqh_lyfs_select").val();
            A.showMask();
            rest.get({
                url: "/common/xzqh?xzqhszDm={xszhszdm}",
                urlParams: {
                    xszhszdm: xzqh
                },
                success: function (bstResult) {
                    A.hideMask();
                    if(bstResult.code=='000') {

                        for(var i in bstResult.dataList){
                            if(bstResult.dataList[i].xzqhDm==xzqh){
                                bstResult.dataList.splice(0,1);
                                break;
                            }
                        }

                        $("#msfpdk_swjg_modal a[name='back_swjg_modal']").off(A.options.clickEvent);
                        $("#msfpdk_swjg_modal a[name='back_swjg_modal']").on(A.options.clickEvent,function(){
                            A.Controller.modal("#msfpdk_swjg_modal");
                        });

                        A.template("#msdkfp_szjdxz_list_tmpl").renderReplace(bstResult, function () {
                            $("#msfpdk_swjg_article li[name='msdkfp-swjg-items'] div.msdkfp-swjg-container").off(A.options.clickEvent).on(A.options.clickEvent, function () {
                                var $parent = $(this).parent("li[name='msdkfp-swjg-items']");
                                if($parent.data("expands")){
                                    $parent.data("expands",false);
                                    subSwjgEaseIn($parent);
                                }else{
                                    var $that = $parent;
                                    $("#msfpdk_swjg_article li[name='msdkfp-swjg-items']").each(function(){
                                        if($(this).data("expands")){
                                            $(this).data("expands",false);
                                            subSwjgEaseIn($(this));
                                        }
                                    });

                                    A.showMask();
                                    var xzqhdm = $(this).data("xzqhdm");
                                    rest.get({
                                        url : "/fp/zrrdk/jdxz/{xzqhdm}",
                                        urlParams : {
                                            xzqhdm : xzqhdm
                                        },
                                        success : function(data){
                                            A.hideMask();

                                            for(var i in data.jdxzList){
                                                if(data.jdxzList[i].xzqhszDm==xzqhdm){
                                                    data.jdxzList.splice(0,1);
                                                    break;
                                                }
                                            }
                                            $that.data("expands",true);
                                            subSwjgEaseOut($that,data,function(){
                                                $that.find("a[name='msdkfp-swjg-subitem']").off(A.options.clickEvent).on(A.options.clickEvent,function(){
                                                    var jdxzdm = $(this).data("jdxzdm");
                                                    var jdxzxzqhdm = $(this).data("xzqhszdm");
                                                    var jdxzmc = $(this).find("span").text();
                                                    $("#msdkfp_component_xzjd input[name='jdxzmc']").val(jdxzmc);
                                                    $("#msdkfp_component_xzjd input[name='jdxzdm']").val(jdxzdm);
                                                    $("#msdkfp_component_xzjd input[name='qxxzqhdm']").val(jdxzxzqhdm);
                                                    A.showMask();
                                                    rest.get({
                                                        url : "/fp/zrrdk/bst/{xzqhszdm}",
                                                        urlParams : {
                                                            xzqhszdm : jdxzxzqhdm
                                                        },
                                                        success:function(swjgData){
                                                            A.hideMask();
                                                            A.template("#msdkfp_swjg_list_tmpl").renderReplace(swjgData);
                                                            A.Controller.modal("#msfpdk_swjg_modal");

                                                        },
                                                        error:function(){
                                                            A.hideMask();
                                                            A.showToast("查询税务机关失败");
                                                        }
                                                    });
                                                });
                                            });
                                        },
                                        error : function(){
                                            A.hideMask();
                                            A.showToast("查询街道乡镇失败");
                                        }
                                    });

                                }
                            });
                        });
                    }else{
                        A.showToast(bstResult.msg);
                        A.Controller.modal("#msfpdk_swjg_modal");
                    }
                },
                error: function () {
                    A.hideMask();
                    A.showToast("查询办税厅失败");
                    A.Controller.modal("#msfpdk_swjg_modal");
                }
            });
        });

        $("#msdkfp_add_addr_modal").on("modalshow",function(){

            // A.showMask();
            // rest.get({
            //     url: '/fp/express/select',
            //     success: function(expressData) {
            //         A.hideMask();
            //         console.log(expressData);
            //     },
            //     error: function(){
            //         A.hideMask();
            //     }
            // });

        });

    }

    $("#msdkfp_add_intro_modal").live("modalshow",function(){

        // $("#msdkfp_add_intro_modal button[name='msdkfp_intro_cancel']").off(A.options.clickEvent).on(A.options.clickEvent,function(){
        //     // $("#msfpdk_form_gmfxx input[name='msdkfp_agree_intro']").val("0");
        //     A.showMask();
        //     A.Controller.modal("#msdkfp_add_intro_modal");
        //     setTimeout(function(){
        //         A.Controller.back();
        //     },500);
        //
        // });

        $("#msdkfp_add_intro_modal button[name='msdkfp_intro_confirm']").off(A.options.clickEvent).on(A.options.clickEvent,function(){
            A.showMask();
            // $("#msfpdk_form_gmfxx input[name='msdkfp_agree_intro']").val("1");
            A.Controller.modal("#msdkfp_add_intro_modal");
            if(reqParam.wsid){
                queryData(reqParam.wsid);
                return;
            }
            setTimeout(function(){
                A.hideMask();
                A.Controller.modal("#msdkfp_add_reg_modal");
            },500);
        });

        A.hideMask();
    });

    // $("#msdkfp_add_intro_modal").live("modalhide",function(){
    //     if($("#msfpdk_form_gmfxx input[name='msdkfp_agree_intro']").val()=="0"){
    //         A.Controller.back();
    //     }
    // });

    $("#msdkfp_add_reg_modal").live("modalshow",function(){

        $("#msdkfp_add_reg_modal button[name='msdkfp_submit_reg']").off(A.options.clickEvent).on(A.options.clickEvent,function(){
            // $("#msfpdk_form_gmfxx input[name='msdkfp_agree_reg']").val("1");
            var sfzjlxDm = $("#msdkfp_add_reg_form select[name='sfzjlxDm']").val();
            var sfzhm = $("#msdkfp_add_reg_form input[name='sfzhm']").val();
            var xm = $("#msdkfp_add_reg_form input[name='xm']").val();
            if(!sfzjlxDm || !sfzhm || !xm){
                A.showToast("请填写自然人登记信息");
                return;
            }

            A.showMask();
            rest.post({
                url : '/fp/zrrdk/zrrdj',
                data : {
                    sfzjlxDm : sfzjlxDm,
                    sfzhm : sfzhm,
                    xm : xm
                },
                success : function(regResut){
                    if(regResut && regResut.code=='000'){
                        A.showToast("自然人登记成功");
                        A.Controller.modal("#msdkfp_add_reg_modal");
                        $("#msfpdk_form_xsfxx input[name='fpdk.xhdwswdjh']").val(regResut.zrrxx.nsrsbh);
                        $("#msfpdk_form_xsfxx input[name='fpdk.xhdwmc']").val(regResut.zrrxx.xm);
                        $("#msfpdk_form_xsfxx input[name='djxh']").val(regResut.zrrxx.djxh);
                        initData();
                    }else{
                        A.hideMask();
                        A.showToast(regResut.msg);
                    }
                },
                error : function(){
                    A.hideMask();
                    A.showToast("自然人登记失败");
                }
            });
        });

        // $("#msdkfp_add_reg_modal button[name='msdkfp_cancel_reg']").off(A.options.clickEvent).on(A.options.clickEvent,function(){
        //     // $("#msfpdk_form_gmfxx input[name='msdkfp_agree_reg']").val("0");
        //     A.showMask();
        //     A.Controller.modal("#msdkfp_add_reg_modal");
        //     setTimeout(function(){
        //         A.Controller.back();
        //     },500);
        // });

    });

    // $("#msdkfp_add_reg_modal").live("modalhide",function(){
    //     if($("#msfpdk_form_gmfxx input[name='msdkfp_agree_reg']").val()=="0"){
    //         A.Controller.back();
    //     }
    // });

    $("#msdkfp_add_section").live("sectionload",function(){
        A.showMask();
        reqParam = A.Component.params(this);
        sessionStorage.removeItem("msfpdk_hwys");
        setTimeout(function(){
            A.Controller.modal("#msdkfp_add_intro_modal");
        },500);
    });

    var queryData = function(wsid){
        rest.get({
            url : "/fp/zrrdk/select/{wsid}",
            urlParams : {
                wsid : wsid
            },
            success : function(result){
                if(result && result.code=="000") {
                    var fpdkxx = result.utFpFpdkPt;
                    A.template("#tmpl_ghfyh").renderReplace(result);

                    $("#msfpdk_form_gmfxx").find("input,select").each(function () {
                        $(this).val(fpdkxx[$(this).data('alias')]);
                    });
                    A.template("#tmpl_xhfyh").renderReplace(result);
                    $("#msfpdk_form_xsfxx").find("input,select").each(function () {
                        $(this).val(fpdkxx[$(this).data('alias')]);
                    });

                    A.template("#tmpl_dkrlx").renderReplace(result);

                    var hwysList = result.utFpFpdkPtHwList;
                    for (var i in hwysList) {
                        hwysList[i].hwysUUID = generateUuid(8, 2);
                        hwysList[i].zspmmc = result.zspmmc;
                        hwysList[i].zspmDm = result.zspmDm;
                    }
                    sessionStorage.setItem("msfpdk_hwys", JSON.stringify(hwysList));
                    var zspmDm = result.zspmDm;

                    $("#msdkfp_form_fpdkxx").find("input,select").each(function () {
                        $(this).val(fpdkxx[$(this).data('alias')]);
                    });

                    var sjhj = math.round(math.add(fpdkxx.hjje,fpdkxx.hjse),2);
                    $("#msdkfp_form_fpdkxx input[name='fpdk.sjhj']").val(sjhj);

                    var fplqfsList = result.fplqfsList;
                    for(var i in fplqfsList){
                        if(fplqfsList[i].fplqfsDm==1){
                            fplqfsList[i].fplqfsForm="self";
                        }else if(fplqfsList[i].fplqfsDm==2){

                        }else{
                            fplqfsList[i].fplqfsForm="express";
                        }
                    }
                    A.template("#msdkfp_lyfs_select_tmpl").renderReplace({fplqfsList:fplqfsList});
                    A.template("#xzqh_lyfs_select_tmpl").renderReplace(result);
                    A.template("#msdkfp_hwys_jldw_tmpl").renderReplace(result);
                    $("#msdkfp_form_fpdkxx input[name='zspmdm']").val(zspmDm);
                    $("#msdkfp_form_fpdkxx textarea[name='fpdk.hwxxbz']").text(fpdkxx.hwxxbz);

                    rest.get({
                        url : "/fp/zrrdk/bst/{jdxzxzqhdm}",
                        urlParams : {
                            jdxzxzqhdm : fpdkxx.qxxzqhdm
                        },
                        success : function(bstResult){
                            A.template("#msdkfp_swjg_list_tmpl").renderReplace(bstResult);
                            var wsInfo = result.utWsInfo;
                            fpdkxx.swjgmc = wsInfo.nsrSwjgMc;
                            fpdkxx.swjgDm = wsInfo.nsrSwjgDm;
                            $("#msfpdk_lyfs_info_form").find("input,select").each(function () {
                                $(this).val(fpdkxx[$(this).data('alias')]);
                            });

                            if(fpdkxx.lqfs==1){
                                $("#msdkfp_lyfs_express input[name='kd.sfzjhm']").val('');
                            }else{
                                $("#msdkfp_lyfs_express").find("input,select").each(function () {
                                    $(this).val(result.utFpFpdkKd[$(this).data('alias')]);
                                });
                                $("#msdkfp_lyfs_terminal input").val('');
                            }

                            $("#msdkfp_swjg_list_select").val(result.utWsInfo.nsrSwjgDm);
                            initBtnEvent();
                            initModalEvent();
                            A.hideMask();

                        },
                        error : function(){
                            A.hideMask();
                            A.showToast("查询办税厅失败");
                            A.Controller.back();
                        }
                    });

                }else{
                    A.hideMask();
                    A.showToast("查询数据失败");
                    A.Controller.back();
                }
            },
            error : function(){
                A.showToast("查询代开信息失败");
                A.hideMask();
                A.Controller.back();
            }
        });
    }

    var saveHwysxx = function(){
        A.showMask();
        var hwysUUID = generateUuid(8,2);

        var hwysParam = {wsid : '', mc : '', ggxh : '', jldw : '', hwsl : '', hsdj : '', bhsdj : '', bhsje : '', zsl : '', se : '', zspmDm : '', hwysUUID:''};

        var formField = {};
        $("#msfpdk_hwys_add_article input,#msfpdk_hwys_add_article select").each(function(){
            formField[$(this).prop('name')] = $(this).val();
        });
        //名称
        formField.mc = $("#msfpdk_hwys_add_article span[name='mc']").text();
        //计量单位名称
        if(formField.jldw)
            formField.jldwmc = $("#msfpdk_hwys_add_article select[name=jldw] option:selected").text();
        else
            formField.jldwmc = "";
        //临时唯一标识
        formField.hwysUUID = hwysUUID;
        $.extend(true,hwysParam,formField);

        var storedHwys = JSON.parse(sessionStorage.getItem("msfpdk_hwys"))||[];
        storedHwys.push(hwysParam);
        sessionStorage.setItem("msfpdk_hwys",JSON.stringify(storedHwys));
        A.showToast("保存完成");
        A.Controller.modal("#msfpdk_hwys_add_modal");
        A.hideMask();
    }

    var updateHwysxx = function(){
        A.showMask();
        var hwysUUID = generateUuid(8,2);
        var hwysParam = {wsid : '', mc : '', ggxh : '', jldw : '', hwsl : '', hsdj : '', bhsdj : '', bhsje : '', zsl : '', se : '', zspmDm : '', hwysUUID:hwysUUID};

        var formField = {};
        $("#msfpdk_hwys_add_article input,#msfpdk_hwys_add_article select").each(function(){
            formField[$(this).prop('name')] = $(this).val();
        });

        //名称
        formField.mc = $("#msfpdk_hwys_add_article span[name='mc']").text();
        //计量单位名称
        if(formField.jldw)
            formField.jldwmc = $("#msfpdk_hwys_add_article select[name=jldw] option:selected").text();
        else
            formField.jldwmc = "";
        $.extend(true,hwysParam,formField);
        var storedHwys = JSON.parse(sessionStorage.getItem("msfpdk_hwys"))||[];
        for(var i=0;i<storedHwys.length;i++){
            if(hwysParam.hwysUUID==storedHwys[i].hwysUUID){
                storedHwys.splice(i,1);
                break;
            }
        }
        storedHwys.push(hwysParam);
        sessionStorage.setItem("msfpdk_hwys",JSON.stringify(storedHwys));
        A.showToast("保存完成");
        A.Controller.modal("#msfpdk_hwys_add_modal");
        A.hideMask();
    }

    var autoCalculate = function($target){
        var hwsl = $("#msfpdk_hwys_add_article input[name='hwsl']").val()||1;
        var zsl = $("#msfpdk_hwys_add_article input[name='zsl']").val();

        var hsdj = $("#msfpdk_hwys_add_article input[name='hsdj']").val()||0;
        var hsje = $("#msfpdk_hwys_add_article input[name='hsje']").val()||0;

        if(hwsl&&zsl){
            var pHwsl = parseFloat(hwsl);
            var pZsl = parseFloat(zsl);

            var pHsdj = parseFloat(hsdj);
            var pHsje = parseFloat(hsje);

            var pBhsdj,pBhsje,pSe;

            if($target.prop('name')=='hwsl'||$target.prop('name')=='hsdj'){
                pHsje = math.round(math.chain(pHwsl).multiply(pHsdj).done(),8);
                $("#msfpdk_hwys_add_article input[name='hsje']").val(pHsje);
            }else if($target.prop('name')=='hsje'){
                pHsdj = math.round(math.chain(pHsje).divide(pHwsl).done(),8);
                $("#msfpdk_hwys_add_article input[name='hsdj']").val(pHsdj);
            }else{
                return;
            }
            pBhsdj = math.round(math.chain(pHsdj).divide((math.add(1,pZsl))).done(),8);
            pBhsje = math.round(math.multiply(pHwsl,pBhsdj),8);//不含税销售额
            pSe = math.round(math.multiply(pBhsje,pZsl),2);

            $("#msfpdk_hwys_add_article input[name='bhsdj']").val(pBhsdj);
            $("#msfpdk_hwys_add_article input[name='bhsje']").val(pBhsje);
            $("#msfpdk_hwys_add_article input[name='se']").val(pSe);
        }

    }

    var validHwysxx = function(){
        var val = $("#msfpdk_hwys_add_article span[name='mc']").text();
        if(!val){
            A.showToast("货物劳务名称不能为空");
            return false;
        }
        if(val.length>25){
            A.showToast("货物劳务名称不能超过25个字符");
            return false;
        }

        val = $("#msfpdk_hwys_add_article input[name='ggxh']").val();
        if(val&&val.length>10){
            A.showToast("规格型号不能超过10个字符");
            return false;
        }

        val = $("#msfpdk_hwys_add_article input[name='hwsl']").val();
        if((val && !/^[0-9]{1,15}\.[0-9]{1,4}$|^[0-9]{1,15}$/.test(val))){
            A.showToast("数量位数不能超过15位，小数不能超过4位");
            return false;
        }
        if(val && val.length>16){
            A.showToast("数量位数不能超过15位，小数不能超过4位");
            return false;
        }

        val = $("#msfpdk_hwys_add_article input[name='hsdj']").val();
        if(val && !/^[0-9]{1,15}\.\d{1,8}$|^[0-9]{1,15}$/.test(val) || ((val.indexOf(".")>=0 && val.length<17) && (val.indexOf(".")<0 && val.length<16))){
            A.showToast("含税单价需小于15位的整数或整数加1-8位小数");
            return false;
        }

        val = $("#msfpdk_hwys_add_article input[name='hsje']").val();
        if(!val){
            A.showToast("含税销售额不能为空");
            return false;
        }
        if(!/^[0-9]{1,15}\.\d{1,8}$|^[0-9]{1,15}$/.test(val) || ((val.indexOf(".")>=0 && val.length<17) && (val.indexOf(".")<0 && val.length<16))){
            A.showToast("含税销售额需小于15位的整数或整数加1-8位小数");
            return false;
        }
        return true;

    }

    $.fn.serializeObject = function(e) {
        var o = {};
        var a = this.serializeArray();
        $.each(a, function() {
            if (o[this.name]) {
                if (!o[this.name].push) {
                    o[this.name] = [o[this.name]];
                }
                o[this.name].push(this.value || '');
            } else {
                var nameArr = this.name.split('.');
                if (nameArr.length > 1) {
                    if (o.hasOwnProperty(nameArr[0])) {
                        o[nameArr[0]][nameArr[1]] = this.value || '';
                    } else {
                        var b = {};
                        b[nameArr[1]] = this.value || '';
                        o[nameArr[0]] = b;
                    }
                } else {
                    o[this.name] = this.value || '';
                }
            }
        });
        return o;
    };

    var submitForm = function(wsztDm){
        A.showMask();
        var reqParam = {};
        reqParam.wsztDm = wsztDm;
        var gmfxxObj = $("#msfpdk_form_gmfxx").serializeObject();

        var xsfxxObj = $("#msfpdk_form_xsfxx").serializeObject();

        var fpdkxxObj = $("#msdkfp_form_fpdkxx").serializeObject();

        var fplqfsxx={},lyfsType = $("#msdkfp_lyfs_select option:selected").data("formtype"),lyfsVal = $("#msdkfp_lyfs_select").val(),kdgsmc=$("#msdkfp_lyfs_select option:selected").text();
        fplqfsxx.fpdk = {};
        fplqfsxx.fpdk.lqfs = lyfsVal;
        fplqfsxx.fpdk.sxzqhdm = $("#xzqh_lyfs_select").val();
        fplqfsxx.fpdk.qxxzqhdm = $("#msdkfp_component_xzjd input[name='qxxzqhdm']").val();
        fplqfsxx.fpdk.jdxzDm = $("#msdkfp_component_xzjd input[name='jdxzdm']").val();
        fplqfsxx.fpdk.jdxzmc = $("#msdkfp_component_xzjd input[name='jdxzmc']").val();
        fplqfsxx.fpdk.zgswjg = $("#msdkfp_swjg_list_select").val();

        if(lyfsType=="express"){
            $.extend(true,fplqfsxx,serializeDivParam($("#msdkfp_lyfs_express")));
            fplqfsxx.fpdk.qprxm = fplqfsxx.kd.sjr;
            fplqfsxx.fpdk.sfzjhm = fplqfsxx.kd.sfzjhm;
            fplqfsxx.fpdk.yddh = fplqfsxx.kd.dhhm;
            fplqfsxx.kd.kdgsDm = lyfsVal;
            fplqfsxx.kd.kdgsMc = kdgsmc;
        }else if(lyfsType=="self"){
            $.extend(true,fplqfsxx,serializeDivParam($("#msdkfp_lyfs_terminal")));
        }else {
            A.hideMask();
            A.showToast("表单提交失败");
            return;
        }

        var hwList = JSON.parse(sessionStorage.getItem("msfpdk_hwys"));

        $.extend(true,reqParam,gmfxxObj,xsfxxObj,fpdkxxObj,fplqfsxx);
        reqParam.hwList = hwList;

        var url;
        var wsid = $("#msfpdk_form_gmfxx input[name='wsid']").val();
        if(!wsid){
            url = "/fp/zrrdk/add";
        }else{
            url = "/fp/zrrdk/edit/"+wsid;
        }

        rest.post({
            url : url,
            data : reqParam,
            success : function(result){
                A.hideMask();
                if(result.code=='000') {
                    if(wsztDm!="B") {
                        A.showToast("保存成功");
                        A.Controller.modal("#msdkfp_confirm_modal");
                        A.Controller.back();
                    }else{
                        A.Controller.modal("#msdkfp_ynsk_modal");
                        A.Controller.section("#tax/msdkfp/msdkfp_success_section");
                    }
                }else
                    A.showToast(result.msg);
            },
            error : function(){
                A.hideMask();
                A.showToast("保存失败");
            }
        });

    }

    var serializeDivParam = function($target){
        var result = {};
        $target.find("input").each(function(){
            var nameFields = $(this).prop('name').split('.');
            if(nameFields.length==1) {
                result[nameFields[0]] = $(this).val();
            }else{
                result[nameFields[0]] = result[nameFields[0]] || {};
                result[nameFields[0]][nameFields[1]] = $(this).val();
            }
        });
        return result;
    }

    var validMsdkfpForm = function(){

        //购买方信息校验
        var val = $("#msfpdk_form_gmfxx input[name='fpdk.ghdwswdjh']").val();
        if(val && !/^[A-Za-z0-9]{1,32}$/.test(val)){
            A.showToast("购买方纳税人识别号只能为数字或字母，长度为1-32个字符");
            return false;
        }

        val = $("#msfpdk_form_gmfxx input[name='fpdk.ghdwmc']").val();
        if(!val){
            A.showToast("购买方名称不能为空");
            return false;
        }
        if(!/^[\u0391-\uFFE5]{1,100}$/.test(val)){
            A.showToast("购买方名称只能为汉字，长度为1-100个字符");
            return false;
        }

        val = $("#msfpdk_form_gmfxx input[name='fpdk.ghdwkhyh']").val();
        if(val && val.length>100){
            A.showToast("购买方银行网点信息不能超过100个字符");
            return false;
        }else if(val && val.length<=100 && !$("#msfpdk_form_gmfxx select[name='fpdk.ghdwyhdm']").val()){
            A.showToast("请选择购买方开户银行");
            return false;
        }else if(!val && $("#msfpdk_form_gmfxx select[name='fpdk.ghdwyhdm']").val()){
            A.showToast("请输入购买方银行网点信息");
            return false;
        }

        //发票代开信息校验
        val = $("#msdkfp_form_fpdkxx select[name='fpdk.dkrlx']").val();
        if(!val){
            A.showToast("请选择代开人类型");
            return false;
        }

        var hwysList;
        try {
            hwysList = JSON.parse(sessionStorage.getItem('msfpdk_hwys'));
        }catch(e){
            A.showToast("请填写货物劳务信息");
            sessionStorage.removeItem('msfpdk_hwys');
            return false;
        }
        if(!hwysList||hwysList.length<=0){
            A.showToast("请填写货物劳务信息");
            return false;
        }

        val = $("#msdkfp_form_fpdkxx input[name='fpdk.hjje']").val();
        if(!val){
            A.showToast("请填写货物劳务信息");
            return false;
        }

        val = $("#msdkfp_form_fpdkxx input[name='fpdk.hjse']").val();
        if(!val){
            A.showToast("请填写货物劳务信息");
            return false;
        }

        //销售方信息校验
        val = $("#msfpdk_form_xsfxx input[name='fpdk.xhdwswdjh']").val();
        if(!val){
            A.showToast("销售方身份证号码不能为空");
            return false;
        }
        if(!/^[A-Za-z0-9]{1,32}$/.test(val)){
            A.showToast("销售方身份证号码只能为数字或字母，长度为1-32个字符");
            return false;
        }

        val = $("#msfpdk_form_xsfxx input[name='fpdk.xhdwmc']").val();
        if(!val){
            A.showToast("销售方姓名不能为空");
            return false;
        }
        if(!/^[\u0391-\uFFE5]{1,100}$/.test(val)){
            A.showToast("销售方姓名只能为汉字，长度为1-100个字符");
            return false;
        }

        val = $("#msfpdk_form_xsfxx input[name='fpdk.xhdwkhyh']").val();
        if(val && val.length>100){
            A.showToast("销售方银行网点信息不能超过100个字符");
            return false;
        }else if(val && val.length<=100 && !$("#msfpdk_form_xsfxx select[name='fpdk.xhdwyhdm']").val()){
            A.showToast("请选择销售方开户银行");
            return false;
        }else if(!val && $("#msfpdk_form_xsfxx select[name='fpdk.xhdwyhdm']").val()){
            A.showToast("请输入销售方银行网点信息");
            return false;
        }

        var dkrlx = $("#msdkfp_form_fpdkxx select[name='fpdk.dkrlx']").val();
        if(dkrlx=='1') {
            val = $("#msfpdk_form_xsfxx input[name='fpdk.xhdwdz']").val();
            if (val && val.length > 100) {
                A.showToast("销售方地址不能超过100个字符");
                return false;
            }

            val = $("#msfpdk_form_xsfxx input[name='fpdk.xhdwyhkh']").val();
            if (val && !/^([0-9]){1,32}$/.test(val)) {
                A.showToast("销售方银行账号只能为数字，长度为1-32位");
                return false;
            }

            val = $("#msfpdk_form_xsfxx input[name='fpdk.xhdwdhhm']").val();
            if (!/^(?:(?:0\d{2,3}[\- ]?[1-9]\d{6,7})|(?:[48]00[\- ]?[1-9]\d{6}))$|^1[3-9]\d{9}$/.test(val)) {
                A.showToast("销售方联系电话须是合法的手机号码或者固定电话号码");
                return false;
            }
        }else{
            A.showToast("当前只支持自然人代开");
            return false;
        }

        //发票领取方式校验
        val = $("#msfpdk_lyfs_info_form select[name='fpdk.lqfs']").val();
        if(!val){
            A.showToast("请选择发票领取方式");
            return false;
        }

        val = $("#xzqh_lyfs_select").val();
        if(!val){
            A.showToast("请选择行政区划");
            return false;
        }

        val = $("#msdkfp_component_xzjd input[name='jdxzmc']").val();
        if(!val){
            A.showToast("请选择所在街道");
            return false;
        }

        val = $("#msdkfp_component_xzjd input[name='qxxzqhdm']").val();
        if(!val){
            A.showToast("请选择所在街道");
            return false;
        }

        val = $("#msdkfp_component_xzjd input[name='jdxzdm']").val();
        if(!val){
            A.showToast("请选择所在街道");
            return false;
        }

        val = $("#msdkfp_swjg_list_select").val();
        if(!val){
            A.showToast("请选择发票领取办税厅");
            return false;
        }

        val = $("#msfpdk_lyfs_info_form select[name='fpdk.lqfs']").val();
        if(val=="1") {
            val = $("#msfpdk_lyfs_info_form input[name='fpdk.qprxm']").val();
            if (!val) {
                A.showToast("签收人姓名不能为空");
                return false;
            }
            if (!/^[\u0391-\uFFE5A-Za-z]{2,8}$/.test(val)) {
                A.showToast("签收人姓名须为汉字或者英文，长度为2-8个字符");
                return false;
            }

            val = $("#msfpdk_lyfs_info_form input[name='fpdk.sfzjhm']").val();
            if (!val) {
                A.showToast("签收人身份证号码不能为空");
                return false;
            }
            if (!/^\d{6}(19|2\d)?\d{2}(0[1-9]|1[012])(0[1-9]|[12]\d|3[01])\d{3}(\d|X)?$/.test(val)) {
                A.showToast("签收人身份证号码不合法");
                return false;
            }

            val = $("#msfpdk_lyfs_info_form input[name='fpdk.yddh']").val();
            if (!val) {
                A.showToast("签收人手机号码不能为空");
                return false;
            }
            if (!/^1[3-9]\d{9}$/.test(val)) {
                A.showToast("签收人手机号码不合法");
                return false;
            }
        }else{
            val = $("#msfpdk_lyfs_info_form input[name='kd.sjr']").val();
            if (!val) {
                A.showToast("收件人姓名不能为空");
                return false;
            }
            if (!/^[\u0391-\uFFE5A-Za-z]{2,8}$/.test(val)) {
                A.showToast("收件人姓名须为汉字或者英文，长度为2-8个字符");
                return false;
            }

            val = $("#msfpdk_lyfs_info_form input[name='kd.dhhm']").val();
            if (!val) {
                A.showToast("收件人手机号码不能为空");
                return false;
            }
            if (!/^1[3-9]\d{9}$/.test(val)) {
                A.showToast("收件人手机号码不合法");
                return false;
            }

            val = $("#msfpdk_lyfs_info_form input[name='kd.dz']").val();
            if (!val) {
                A.showToast("收件人收货地址不能为空");
                return false;
            }
            if (!/^[\u0391-\uFFE5A-Za-z0-9]{1,60}$/.test(val)) {
                A.showToast("收件人收货地址不能超过60个字符");
                return false;
            }

            val = $("#msfpdk_lyfs_info_form input[name='kd.sfzjhm']").val();
            if (!val) {
                A.showToast("收件人身份证号码不能为空");
                return false;
            }
            if (!/^\d{6}(19|2\d)?\d{2}(0[1-9]|1[012])(0[1-9]|[12]\d|3[01])\d{3}(\d|X)?$/.test(val)) {
                A.showToast("收件人身份证号码不合法");
                return false;
            }


        }

        return true;

    }


});